Learn R Programming

xportr (version 0.4.3)

xportr_options_list: A list with all the supported options of xportr

Description

An internal list with all the supported options of xportr with defaults

Usage

xportr_options_list

Arguments

Format

An object of class list of length 17.